/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2008, Red Hat Middleware LLC, and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.jca.spi;

import java.util.Set;

import javax.resource.spi.ActivationSpec;

/**
 * The EndpointActivationBus.
 * 
 * @author <a href="mailto:adrian@jboss.org">Adrian Brock</a>
 * @author <a href="mailto:jesper.pedersen@jboss.org">Jesper Pedersen</a>
 * @version $Revision: $
 */
public interface EndpointActivationBus
{
   /**
    * Activate an Endpoint
    * @param endpoint The endpoint
    * @param spec The activation spec
    * @return The endpoint activation
    */
   EndpointActivation activate(Endpoint endpoint, ActivationSpec spec);

   /**
    * Activate an Endpoint
    * @param endpoint The endpoint
    * @param properties Activation configuration properties
    * @param selection The resource adaptor selection
    * @return The endpoint activation
    */
   EndpointActivation activate(Endpoint endpoint, Set<ActivationConfigProperty> properties, RarSelection selection);

   /**
    * Determine the dependency name for the rar
    * @param properties The config properties
    * @param selection The rar selection parameters
    * @return The dependency name, e.g. JMX object name or MC name or null if it cannot be determined
    */
   String resolveRarContext(Set<ActivationConfigProperty> properties, RarSelection selection);
}
